==> psiz-0.11.0-py3-none-any.whl: psiz/keras/constraints/greater_equal_than.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 The PsiZ Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ============================================================================
"""Module of custom TensorFlow constraints.

Classes:
    GreaterEqualThan:

"""

import tensorflow as tf
from tensorflow.keras import backend
from tensorflow.keras import constraints


@tf.keras.utils.register_keras_serializable(package="psiz.keras.constraints")
class GreaterEqualThan(constraints.Constraint):
    """Constrains the weights to be greater/equal than a value."""

    def __init__(self, min_value=0.0):
        """Initialize.

        Args:
            min_value: The minimum allowed weight value.

        """
        self.min_value = min_value

    def __call__(self, w):
        """Call."""
        w = w - self.min_value
        w = w * tf.cast(tf.math.greater_equal(w, 0.0), backend.floatx())
        w = w + self.min_value
        return w

    def get_config(self):
        """Return configuration."""
        return {"min_value": self.min_value}

==> psiz-0.12.4-py3-none-any.whl: psiz/keras/constraints/greater_equal_than.py <==
# -*- coding: utf-8 -*-
# Copyright 2024 The PsiZ Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ============================================================================
"""Module of custom TensorFlow constraints.

Classes:
    GreaterEqualThan:

"""


import keras


@keras.saving.register_keras_serializable(package="psiz.keras.constraints")
class GreaterEqualThan(keras.constraints.Constraint):
    """Constrains the weights to be greater/equal than a value."""

    def __init__(self, min_value=0.0):
        """Initialize.

        Args:
            min_value: The minimum allowed weight value.

        """
        self.min_value = min_value

    def __call__(self, w):
        """Call."""
        w = w - self.min_value
        w = w * keras.ops.cast(keras.ops.greater_equal(w, 0.0), keras.backend.floatx())
        w = w + self.min_value
        return w

    def get_config(self):
        """Return configuration."""
        return {"min_value": self.min_value}
